@@ -279,6 +279,7 @@ Example
 
 __all__ = (
     "MDNavigationRail",
+    "MDNavigationRailItem",
     "MDNavigationRailFabButton",
     "MDNavigationRailMenuButton",
 )
@@ -852,8 +853,8 @@ class MDNavigationRail(MDCard, FakeRectangularElevationBehavior):
     and defaults to `'Roboto'`.
     """
 
-    def __init__(self, **kwargs):
-        super().__init__(**kwargs)
+    def __init__(self, *args, **kwargs):
+        super().__init__(*args, **kwargs)
         Clock.schedule_once(self.set_pos_menu_fab_buttons)
         Clock.schedule_once(self.set_current_selected_item)
         self.register_event_type("on_item_press")
