@@ -327,7 +327,7 @@ Material design 3 style
     :align: center
 """
 
-__all__ = ("MDTopAppBar", "MDBottomAppBar", "MDToolbar")
+__all__ = ("MDTopAppBar", "MDBottomAppBar")
 
 import os
 from math import cos, radians, sin
@@ -356,6 +356,7 @@ from kivymd import uix_path
 from kivymd.color_definitions import text_colors
 from kivymd.theming import ThemableBehavior
 from kivymd.uix.behaviors import (
+    DeclarativeBehavior,
     FakeRectangularElevationBehavior,
     SpecificBackgroundColorBehavior,
 )
@@ -555,7 +556,7 @@ class NotchedBox(
         return points
 
 
-class MDTopAppBar(NotchedBox, WindowController):
+class MDTopAppBar(DeclarativeBehavior, NotchedBox, WindowController):
     """
     :Events:
         `on_action_button`
@@ -945,18 +946,6 @@ class MDTopAppBar(NotchedBox, WindowController):
     and defaults to `'small'`.
     """
 
-    round = NumericProperty("10dp", deprecated=True)
-    """
-    Rounding the corners at the notch for a button.
-    Only for :class:`~MDBottomAppBar` class.
-
-    .. deprecated:: 1.0.0
-        Don't use this attribute.
-
-    :attr:`round` is an :class:`~kivy.properties.NumericProperty`
-    and defaults to `'10dp'`.
-    """
-
     # List of action buttons (ActionTopAppBarButton instance) that have been
     # .added to the overflow
     _hidden_items = []
@@ -1309,7 +1298,8 @@ class MDTopAppBar(NotchedBox, WindowController):
         if material_style_value == "M2":
             self.anchor_title = "left"
         elif material_style_value == "M3" and self.type != "bottom":
-            self.anchor_title = "center"
+            if not self.anchor_title:
+                self.anchor_title = "center"
         elif material_style_value == "M3" and self.type == "bottom":
             self.anchor_title = "left"
         return self.anchor_title
@@ -1375,7 +1365,7 @@ class MDTopAppBar(NotchedBox, WindowController):
             ][self.theme_cls.primary_hue]
 
 
-class MDBottomAppBar(FloatLayout):
+class MDBottomAppBar(DeclarativeBehavior, FloatLayout):
     md_bg_color = ColorProperty([0, 0, 0, 0])
     """
     Color toolbar.
@@ -1384,27 +1374,11 @@ class MDBottomAppBar(FloatLayout):
     and defaults to `[0, 0, 0, 0]`.
     """
 
-    def __init__(self, **kwargs):
-        super().__init__(**kwargs)
+    def __init__(self, *args, **kwargs):
+        super().__init__(*args, **kwargs)
         self.size_hint_y = None
 
     def add_widget(self, widget, index=0, canvas=None):
         if isinstance(widget, MDTopAppBar):
             super().add_widget(widget)
             return super().add_widget(widget.action_button)
-
-
-class MDToolbar(MDTopAppBar):
-    """
-    .. deprecated:: 1.0.0
-
-        Use :class:`~MDTopAppBar` class instead.
-    """
-
-    def __init__(self, **kwargs):
-        super().__init__(**kwargs)
-        Logger.warning(
-            "KivyMD: "
-            "The `MDToolbar` class has been deprecated. Use the `MDTopAppBar` "
-            "class instead."
-        )
