@@ -8,6 +8,9 @@ import sqlite3
 
 import RNS.vendor.umsgpack as msgpack
 
+if RNS.vendor.platformutils.get_platform() == "android":
+    from jnius import autoclass, cast
+
 class PropagationNodeDetector():
     EMITTED_DELTA_GRACE = 300
     EMITTED_DELTA_IGNORE = 10
@@ -58,7 +61,9 @@ class SidebandCore():
     CONV_GROUP     = 0x02
     CONV_BROADCAST = 0x03
 
-    MAX_ANNOUNCES  = 64
+    MAX_ANNOUNCES  = 48
+
+    JOB_INTERVAL   = 1
 
     aspect_filter = "lxmf.delivery"
     def received_announce(self, destination_hash, announced_identity, app_data):
@@ -66,37 +71,60 @@ class SidebandCore():
         # stream logger
         self.log_announce(destination_hash, app_data, dest_type=SidebandCore.aspect_filter)
 
-    def __init__(self, owner_app):
+    def __init__(self, owner_app, is_service=False, is_client=False, android_app_dir=None, verbose=False):
+        self.is_service = is_service
+        self.is_client = is_client
+
+        if not self.is_service and not self.is_client:
+            self.is_standalone = True
+        else:
+            self.is_standalone = False
+
+        self.log_verbose = verbose
         self.owner_app = owner_app
         self.reticulum = None
 
-        self.app_dir       = plyer.storagepath.get_home_dir()+"/.sideband"
+        self.app_dir       = plyer.storagepath.get_home_dir()+"/.config/sideband"
+        if self.app_dir.startswith("file://"):
+            self.app_dir   = self.app_dir.replace("file://", "")
         
         self.rns_configdir = None
-        if RNS.vendor.platformutils.get_platform() == "android":
-            self.app_dir = plyer.storagepath.get_application_dir()+"/io.unsigned.sideband/files/"
+        if RNS.vendor.platformutils.is_android():
+            self.app_dir = android_app_dir+"/io.unsigned.sideband/files/"
             self.rns_configdir = self.app_dir+"/app_storage/reticulum"
+            self.asset_dir     = self.app_dir+"/app/assets"
+        elif RNS.vendor.platformutils.is_darwin():
+            core_path          = os.path.abspath(__file__)
+            self.asset_dir     = core_path.replace("/sideband/core.py", "/assets")
+        else:
+            self.asset_dir     = plyer.storagepath.get_application_dir()+"/sbapp/assets"
+
+        self.icon              = self.asset_dir+"/icon.png"
+        self.icon_48           = self.asset_dir+"/icon_48.png"
+        self.icon_32           = self.asset_dir+"/icon_32.png"
+        self.icon_macos        = self.asset_dir+"/icon_macos.png"
+        self.notification_icon = self.asset_dir+"/notification_icon.png"
 
         if not os.path.isdir(self.app_dir+"/app_storage"):
             os.makedirs(self.app_dir+"/app_storage")
 
-        self.asset_dir     = self.app_dir+"/assets"
-        self.kv_dir        = self.app_dir+"/views/kv"
         self.config_path   = self.app_dir+"/app_storage/sideband_config"
         self.identity_path = self.app_dir+"/app_storage/primary_identity"
         self.db_path       = self.app_dir+"/app_storage/sideband.db"
         self.lxmf_storage  = self.app_dir+"/app_storage/"
+        
+        self.first_run     = True
 
         try:
             if not os.path.isfile(self.config_path):
                 self.__init_config()
             else:
                 self.__load_config()
+                self.first_run = False
                 
         except Exception as e:
             RNS.log("Error while configuring Sideband: "+str(e), RNS.LOG_ERROR)
 
-
         # Initialise Reticulum configuration
         if RNS.vendor.platformutils.get_platform() == "android":
             try:
@@ -121,8 +149,6 @@ class SidebandCore():
         RNS.Transport.register_announce_handler(self)
         RNS.Transport.register_announce_handler(self.propagation_detector)
 
-        self.start()
-
 
     def __init_config(self):
         RNS.log("Creating new Sideband configuration...")
@@ -135,6 +161,7 @@ class SidebandCore():
         self.config = {}
         # Settings
         self.config["display_name"] = "Anonymous Peer"
+        self.config["dark_ui"] = False
         self.config["start_announce"] = False
         self.config["propagation_by_default"] = False
         self.config["home_node_as_broadcast_repeater"] = False
@@ -159,34 +186,62 @@ class SidebandCore():
         self.config["connect_i2p_ifac_netname"] = ""
         self.config["connect_i2p_ifac_passphrase"] = ""
 
-        self.__save_config()
-
         if not os.path.isfile(self.db_path):
             self.__db_init()
+        else:
+            self._db_initstate()
+            self._db_initpersistent()
 
+        self.__save_config()
+
+    def should_persist_data(self):
+        if self.reticulum != None:
+            self.reticulum._should_persist_data()
+
+        self.save_configuration()
 
     def __load_config(self):
-        RNS.log("Loading Sideband identity...")
+        RNS.log("Loading Sideband identity...", RNS.LOG_DEBUG)
         self.identity = RNS.Identity.from_file(self.identity_path)
 
-        RNS.log("Loading Sideband configuration... "+str(self.config_path))
+        RNS.log("Loading Sideband configuration... "+str(self.config_path), RNS.LOG_DEBUG)
         config_file = open(self.config_path, "rb")
         self.config = msgpack.unpackb(config_file.read())
         config_file.close()
 
+        # Migration actions from earlier config formats
+        if not "dark_ui" in self.config:
+            self.config["dark_ui"] = True
+
+        # Make sure we have a database
         if not os.path.isfile(self.db_path):
             self.__db_init()
+        else:
+            self._db_initstate()
+            self._db_initpersistent()
 
 
+    def __reload_config(self):
+        RNS.log("Reloading Sideband configuration... "+str(self.config_path), RNS.LOG_DEBUG)
+        config_file = open(self.config_path, "rb")
+        self.config = msgpack.unpackb(config_file.read())
+        config_file.close()
+
+        self.update_active_lxmf_propagation_node()
+
     def __save_config(self):
-        RNS.log("Saving Sideband configuration...")
+        RNS.log("Saving Sideband configuration...", RNS.LOG_DEBUG)
         config_file = open(self.config_path, "wb")
         config_file.write(msgpack.packb(self.config))
         config_file.close()
 
-    
+        if self.is_client:
+            self.setstate("wants.settings_reload", True)
+
+    def reload_configuration(self):
+        self.__reload_config()
+
     def save_configuration(self):
-        RNS.log("Saving configuration")
         self.__save_config()
 
     def set_active_propagation_node(self, dest):
@@ -203,11 +258,32 @@ class SidebandCore():
                 RNS.log("Error while setting LXMF propagation node: "+str(e), RNS.LOG_ERROR)
 
 
+    def notify(self, title, content, group=None, context_id=None):
+        notifications_enabled = True
+
+        if notifications_enabled:
+            if RNS.vendor.platformutils.get_platform() == "android":
+                if self.getpersistent("permissions.notifications"):
+                    notifications_permitted = True
+                else:
+                    notifications_permitted = False
+            else:
+                notifications_permitted = True
+
+            if notifications_permitted:
+                if RNS.vendor.platformutils.get_platform() == "android":
+                    if self.is_service:
+                        self.owner_service.android_notification(title, content, group=group, context_id=context_id)
+                    else:
+                        plyer.notification.notify(title, content, notification_icon=self.notification_icon, context_override=None)
+                else:
+                    plyer.notification.notify(title, content, app_icon=self.icon_32)
+
     def log_announce(self, dest, app_data, dest_type):
         try:
             RNS.log("Received "+str(dest_type)+" announce for "+RNS.prettyhexrep(dest)+" with data: "+app_data.decode("utf-8"))
             self._db_save_announce(dest, app_data, dest_type)
-            self.owner_app.flag_new_announces = True
+            self.setstate("app.flags.new_announces", True)
 
         except Exception as e:
             RNS.log("Exception while decoding LXMF destination announce data:"+str(e))
@@ -326,6 +402,40 @@ class SidebandCore():
         else:
             return []
 
+    def service_available(self):
+        service_heartbeat = self.getstate("service.heartbeat")
+        if not service_heartbeat:
+            return False
+        else:
+            try:
+                if time.time() - service_heartbeat > 2.5:
+                    return False
+                else:
+                    return True
+            except:
+                return False
+
+    def gui_foreground(self):
+        return self._db_getstate("app.foreground")
+
+    def gui_display(self):
+        return self._db_getstate("app.displaying")
+
+    def gui_conversation(self):
+        return self._db_getstate("app.active_conversation")
+
+    def setstate(self, prop, val):
+        self._db_setstate(prop, val)
+
+    def getstate(self, prop):
+        return self._db_getstate(prop)
+
+    def setpersistent(self, prop, val):
+        self._db_setpersistent(prop, val)
+
+    def getpersistent(self, prop):
+        return self._db_getpersistent(prop)
+
     def __event_conversations_changed(self):
         pass
 
@@ -345,6 +455,100 @@ class SidebandCore():
         dbc.execute("DROP TABLE IF EXISTS announce")
         dbc.execute("CREATE TABLE announce (id PRIMARY KEY, received INTEGER, source BLOB, data BLOB, dest_type BLOB)")
 
+        dbc.execute("DROP TABLE IF EXISTS state")
+        dbc.execute("CREATE TABLE state (property BLOB PRIMARY KEY, value BLOB)")
+
+        dbc.execute("DROP TABLE IF EXISTS persistent")
+        dbc.execute("CREATE TABLE persistent (property BLOB PRIMARY KEY, value BLOB)")
+
+        db.commit()
+        db.close()
+
+    def _db_initstate(self):
+        db = sqlite3.connect(self.db_path)
+        dbc = db.cursor()
+
+        dbc.execute("DROP TABLE IF EXISTS state")
+        dbc.execute("CREATE TABLE state (property BLOB PRIMARY KEY, value BLOB)")
+        self._db_setstate("database_ready", True)
+
+    def _db_getstate(self, prop):
+        db = sqlite3.connect(self.db_path)
+        dbc = db.cursor()
+        
+        query = "select * from state where property=:uprop"
+        dbc.execute(query, {"uprop": prop.encode("utf-8")})
+        result = dbc.fetchall()
+        db.close()
+
+        if len(result) < 1:
+            return None
+        else:
+            try:
+                entry = result[0]
+                val = msgpack.unpackb(entry[1])
+                return val
+            except Exception as e:
+                RNS.log("Could not unpack state value from database for property \""+str(prop)+"\". The contained exception was: "+str(e), RNS.LOG_ERROR)
+                return None
+
+    def _db_setstate(self, prop, val):
+        db = sqlite3.connect(self.db_path)
+        dbc = db.cursor()
+        uprop = prop.encode("utf-8")
+        bval = msgpack.packb(val)
+
+        if self._db_getstate(prop) == None:
+            query = "INSERT INTO state (property, value) values (?, ?)"
+            data = (uprop, bval)
+            dbc.execute(query, data)
+        else:
+            query = "UPDATE state set value=:bval where property=:uprop;"
+            dbc.execute(query, {"bval": bval, "uprop": uprop})
+
+        db.commit()
+        db.close()
+
+    def _db_initpersistent(self):
+        db = sqlite3.connect(self.db_path)
+        dbc = db.cursor()
+
+        dbc.execute("CREATE TABLE IF NOT EXISTS persistent (property BLOB PRIMARY KEY, value BLOB)")
+
+    def _db_getpersistent(self, prop):
+        db = sqlite3.connect(self.db_path)
+        dbc = db.cursor()
+        
+        query = "select * from persistent where property=:uprop"
+        dbc.execute(query, {"uprop": prop.encode("utf-8")})
+        result = dbc.fetchall()
+        db.close()
+
+        if len(result) < 1:
+            return None
+        else:
+            try:
+                entry = result[0]
+                val = msgpack.unpackb(entry[1])
+                return val
+            except Exception as e:
+                RNS.log("Could not unpack persistent value from database for property \""+str(prop)+"\". The contained exception was: "+str(e), RNS.LOG_ERROR)
+                return None
+
+    def _db_setpersistent(self, prop, val):
+        db = sqlite3.connect(self.db_path)
+        dbc = db.cursor()
+        uprop = prop.encode("utf-8")
+        bval = msgpack.packb(val)
+
+        if self._db_getpersistent(prop) == None:
+            query = "INSERT INTO persistent (property, value) values (?, ?)"
+            data = (uprop, bval)
+            dbc.execute(query, data)
+        else:
+            query = "UPDATE persistent set value=:bval where property=:uprop;"
+            dbc.execute(query, {"bval": bval, "uprop": uprop})
+
         db.commit()
         db.close()
 
@@ -405,7 +609,6 @@ class SidebandCore():
 
             return convs
 
-
     def _db_announces(self):
         db = sqlite3.connect(self.db_path)
         dbc = db.cursor()
@@ -433,7 +636,6 @@ class SidebandCore():
 
             return announces
 
-
     def _db_conversation(self, context_dest):
         db = sqlite3.connect(self.db_path)
         dbc = db.cursor()
@@ -459,7 +661,6 @@ class SidebandCore():
             conv["data"] = msgpack.unpackb(c[7])
             return conv
 
-
     def _db_clear_conversation(self, context_dest):
         RNS.log("Clearing conversation with "+RNS.prettyhexrep(context_dest))
         db = sqlite3.connect(self.db_path)
@@ -619,7 +820,6 @@ class SidebandCore():
 
             return messages
 
-
     def _db_save_lxm(self, lxm, context_dest):    
         state = lxm.state
 
@@ -672,7 +872,11 @@ class SidebandCore():
         db.close()
 
     def lxmf_announce(self):
-        self.lxmf_destination.announce()
+        if self.is_standalone or self.is_service:
+            self.lxmf_destination.announce()
+            self.setstate("wants.announce", False)
+        else:
+            self.setstate("wants.announce", True)
 
     def is_known(self, dest_hash):
         try:
@@ -695,13 +899,28 @@ class SidebandCore():
             RNS.log("Error while querying for key: "+str(e), RNS.LOG_ERROR)
             return False
 
+    def _service_jobs(self):
+        if self.is_service:
+            while True:
+                time.sleep(SidebandCore.JOB_INTERVAL)
+                if self.getstate("wants.announce"):
+                    self.lxmf_announce()
+
     def __start_jobs_deferred(self):
         if self.config["start_announce"]:
-            self.lxmf_destination.announce()
+            self.lxmf_announce()
 
+        if self.is_service:
+            self.service_thread = threading.Thread(target=self._service_jobs, daemon=True)
+            self.service_thread.start()
+        
     def __start_jobs_immediate(self):
-        self.reticulum = RNS.Reticulum(configdir=self.rns_configdir)
-        RNS.log("Reticulum started, activating LXMF...")
+        if self.log_verbose:
+            selected_level = 7
+        else:
+            selected_level = 2
+
+        self.reticulum = RNS.Reticulum(configdir=self.rns_configdir, loglevel=selected_level)
 
         if RNS.vendor.platformutils.get_platform() == "android":
             if not self.reticulum.is_connected_to_shared_instance:
@@ -812,7 +1031,7 @@ class SidebandCore():
                         RNS.log("Error while adding I2P Interface. The contained exception was: "+str(e))
                         self.interface_i2p = None
 
-
+        RNS.log("Reticulum started, activating LXMF...")
         self.message_router = LXMF.LXMRouter(identity = self.identity, storagepath = self.lxmf_storage, autopeer = True)
         self.message_router.register_delivery_callback(self.lxmf_delivery)
 
@@ -821,6 +1040,9 @@ class SidebandCore():
 
         self.rns_dir = RNS.Reticulum.configdir
 
+        self.update_active_lxmf_propagation_node()
+
+    def update_active_lxmf_propagation_node(self):
         if self.config["lxmf_propagation_node"] != None and self.config["lxmf_propagation_node"] != "":
             self.set_active_propagation_node(self.config["lxmf_propagation_node"])
         else:
@@ -852,7 +1074,6 @@ class SidebandCore():
             dest = RNS.Destination(dest_identity, RNS.Destination.OUT, RNS.Destination.SINGLE, "lxmf", "delivery")
             source = self.lxmf_destination
             
-            # TODO: Add setting
             if propagation:
                 desired_method = LXMF.LXMessage.PROPAGATED
             else:
@@ -899,10 +1120,14 @@ class SidebandCore():
         return True
 
     def lxm_ingest(self, message, originator = False):
+        should_notify = False
+        is_trusted = False
+
         if originator:
             context_dest = message.destination_hash
         else:
             context_dest = message.source_hash
+            is_trusted = self.is_trusted(context_dest)
 
         if self._db_message(message.hash):
             RNS.log("Message exists, setting state to: "+str(message.state), RNS.LOG_DEBUG)
@@ -911,22 +1136,38 @@ class SidebandCore():
             RNS.log("Message does not exist, saving", RNS.LOG_DEBUG)
             self._db_save_lxm(message, context_dest)
 
+            if is_trusted:
+                should_notify = True
+
         if self._db_conversation(context_dest) == None:
             self._db_create_conversation(context_dest)
-            self.owner_app.flag_new_conversations = True
+            self.setstate("app.flags.new_conversations", True)
 
-        if self.owner_app.root.ids.screen_manager.current == "messages_screen":
-            if self.owner_app.root.ids.messages_scrollview.active_conversation != context_dest:
+        if self.gui_display() == "messages_screen":
+            if self.gui_conversation() != context_dest:
                 self.unread_conversation(context_dest)
-                self.owner_app.flag_unread_conversations = True
+                self.setstate("app.flags.unread_conversations", True)
+            else:
+                if self.gui_foreground():
+                    should_notify = False
         else:
             self.unread_conversation(context_dest)
-            self.owner_app.flag_unread_conversations = True
+            self.setstate("app.flags.unread_conversations", True)
 
-        try:
-            self.owner_app.conversation_update(context_dest)
-        except Exception as e:
-            RNS.log("Error in conversation update callback: "+str(e))
+            if self.gui_display() == "conversations_screen" and self.gui_foreground():
+                should_notify = False
+
+        if self.is_client:
+            should_notify = False
+
+        if should_notify:
+            nlen = 128
+            text = message.content.decode("utf-8")
+            notification_content = text[:nlen]
+            if len(text) > nlen:
+                text += "..."
+
+            self.notify(title=self.peer_display_name(context_dest), content=notification_content, group="LXM", context_id=RNS.hexrep(context_dest, delimit=False))
 
 
     def start(self):
@@ -936,6 +1177,8 @@ class SidebandCore():
         thread = threading.Thread(target=self.__start_jobs_deferred)
         thread.setDaemon(True)
         thread.start()
+
+        self._db_setstate("core.started", True)
         RNS.log("Sideband Core "+str(self)+" started")
 
     def request_lxmf_sync(self, limit = None):
