@@ -40,8 +40,7 @@ class Announces():
         self.clear_list()
         self.announces = self.app.sideband.list_announces()
         self.update_widget()
-
-        self.app.flag_new_announces = False
+        self.app.sideband.setstate("app.flags.new_announces", False)
 
     def update_widget(self):
         if self.list == None:
@@ -74,6 +73,7 @@ class Announces():
                         dialog = MDDialog(
                             text=ad_text,
                             buttons=[ yes_button ],
+                            # elevation=0,
                         )
                         def dl_yes(s):
                             dialog.dismiss()
@@ -97,7 +97,6 @@ class Announces():
                     disp_name = "Unknown Announce"
                     iconl = IconLeftWidget(icon="progress-question")
 
-
                 item = OneLineAvatarIconListItem(text=time_string+": "+disp_name, on_release=gen_info(time_string, context_dest, a_data, dest_type))
                 item.add_widget(iconl)
                 item.sb_uid = context_dest
@@ -113,6 +112,7 @@ class Announces():
                         dialog = MDDialog(
                             text="Delete announce?",
                             buttons=[ yes_button, no_button ],
+                            # elevation=0,
                         )
                         def dl_yes(s):
                             dialog.dismiss()
@@ -177,6 +177,8 @@ class Announces():
                     items=dm_items,
                     position="center",
                     width_mult=4,
+                    elevation=1,
+                    radius=dp(3),
                 )
 
                 def callback_factory(ref):
