@@ -1,8 +1,51 @@
 root_layout = """
+#: import NoTransition kivy.uix.screenmanager.NoTransition
+#: import SlideTransition kivy.uix.screenmanager.SlideTransition
+
 MDNavigationLayout:
+    md_bg_color: app.theme_cls.bg_darkest
 
     ScreenManager:
         id: screen_manager
+        transition: SlideTransition()
+        # transition: NoTransition()
+
+        MDScreen:
+            name: "starting_screen"
+                 
+            AnchorLayout:
+                anchor_x: "center"
+                anchor_y: "center"
+                padding: dp(64)
+
+                BoxLayout:
+                    spacing: dp(36)
+                    orientation: 'vertical'
+                    size_hint_y: None
+
+                    MDLabel:
+                        id: connecting_info
+                        halign: "center"
+                        text: "Please Wait"
+                        font_size: "32dp"
+                        size_hint_y: None
+                        text_size: self.width, None
+                        height: self.texture_size[1]
+
+                    MDIconButton:
+                        pos_hint: {"center_x": .5, "center_y": .5}
+                        icon: "transit-connection-variant"
+                        icon_size: "72dp"
+
+                    MDLabel:
+                        id: connecting_info
+                        halign: "center"
+                        text: "Substantiating Reticulum"
+                        font_size: "32dp"
+                        size_hint_y: None
+                        text_size: self.width, None
+                        height: self.texture_size[1]
+
 
         MDScreen:
             name: "conversations_screen"
@@ -12,8 +55,8 @@ MDNavigationLayout:
 
                 MDTopAppBar:
                     title: "Conversations"
-                    elevation: 10
-                    pos_hint: {"top": 1}
+                    anchor_title: "left"
+                    elevation: 2
                     left_action_items:
                         [
                         ['menu', lambda x: nav_drawer.set_state("open")],
@@ -38,9 +81,9 @@ MDNavigationLayout:
 
                 MDTopAppBar:
                     id: messages_toolbar
+                    anchor_title: "left"
                     title: "Messages"
-                    elevation: 10
-                    pos_hint: {"top": 1}
+                    elevation: 2
                     left_action_items:
                         [['menu', lambda x: nav_drawer.set_state("open")]]
                     right_action_items:
@@ -55,9 +98,9 @@ MDNavigationLayout:
                     do_scroll_y: True
 
                 BoxLayout:
-                    orientation: "vertical"
                     id: no_keys_part
-                    padding: [dp(28), dp(16), dp(16), dp(16)]
+                    orientation: "vertical"
+                    padding: [dp(16), dp(0), dp(16), dp(16)]
                     spacing: dp(24)
                     size_hint_y: None
                     height: self.minimum_height + dp(64)
@@ -69,14 +112,12 @@ MDNavigationLayout:
                     MDRectangleFlatIconButton:
                         icon: "key-wireless"
                         text: "Query Network For Keys"
-                        # padding: [dp(16), dp(16), dp(16), dp(16)]
                         on_release: root.ids.screen_manager.app.key_query_action(self)
                     
 
                 BoxLayout:
                     id: message_input_part
-                    # orientation: "vertical"
-                    padding: [dp(28), dp(16), dp(16), dp(16)]
+                    padding: [dp(16), dp(0), dp(16), dp(16)]
                     spacing: dp(24)
                     size_hint_y: None
                     height: self.minimum_height
@@ -91,7 +132,9 @@ MDNavigationLayout:
                     MDRectangleFlatIconButton:
                         icon: "transfer-up"
                         text: "Send"
-                        # padding: [dp(16), dp(16), dp(16), dp(16)]
+                        padding: [dp(10), dp(13), dp(10), dp(14)]
+                        icon_size: dp(24)
+                        font_size: dp(16)
                         on_release: root.ids.screen_manager.app.message_send_action(self)
                         
 
@@ -103,8 +146,8 @@ MDNavigationLayout:
 
                 MDTopAppBar:
                     title: "Local Broadcasts"
-                    elevation: 10
-                    pos_hint: {"top": 1}
+                    anchor_title: "left"
+                    elevation: 2
                     left_action_items:
                         [['menu', lambda x: nav_drawer.set_state("open")]]
 
@@ -116,7 +159,7 @@ MDNavigationLayout:
                         spacing: "24dp"
                         size_hint_y: None
                         height: self.minimum_height
-                        padding: dp(64)
+                        padding: [dp(35), dp(35), dp(35), dp(35)]
 
                         MDLabel:
                             id: broadcasts_info
@@ -135,8 +178,8 @@ MDNavigationLayout:
 
                 MDTopAppBar:
                     title: "Connectivity"
-                    elevation: 10
-                    pos_hint: {"top": 1}
+                    anchor_title: "left"
+                    elevation: 2
                     left_action_items:
                         [['menu', lambda x: nav_drawer.set_state("open")]]
                     right_action_items:
@@ -149,17 +192,13 @@ MDNavigationLayout:
 
                     MDBoxLayout:
                         orientation: "vertical"
-                        spacing: "24dp"
+                        spacing: "8dp"
                         size_hint_y: None
                         height: self.minimum_height
-                        padding: dp(16)
+                        padding: [dp(28), dp(48), dp(28), dp(16)]
 
                         MDLabel:
-                            text: ""
-                            font_style: "H6"
-
-                        MDLabel:
-                            text: "Configuring Connectivity"
+                            text: "Configuring Connectivity\\n"
                             font_style: "H6"
 
                         MDLabel:
@@ -171,11 +210,27 @@ MDNavigationLayout:
                             height: self.texture_size[1]
 
 
+                        # MDBoxLayout:
+                        #     orientation: "horizontal"
+                        #     size_hint_y: None
+                        #     padding: [0,0,dp(24),0]
+                        #     height: dp(48)
+                            
+                        #     MDLabel:
+                        #         text: "Send via Propagation Node by default"
+                        #         font_style: "H6"
+
+                        #     MDSwitch:
+                        #         id: settings_lxmf_delivery_by_default
+                        #         pos_hint: {"center_y": 0.3}
+                        #         disabled: False
+                        #         active: False
+
                         MDBoxLayout:
                             orientation: "horizontal"
-                            # spacing: "24dp"
+                            padding: [0,0,dp(24),0]
                             size_hint_y: None
-                            height: dp(48)
+                            height: dp(24)
                             
                             MDLabel:
                                 id: connectivity_local_label
@@ -184,38 +239,41 @@ MDNavigationLayout:
 
                             MDSwitch:
                                 id: connectivity_use_local
+                                pos_hint: {"center_y": 0.3}
                                 active: False
 
-                        MDLabel:
-                            text: ""
-                            font_size: dp(16)
+                        MDBoxLayout:
+                            id: connectivity_local_fields
+                            orientation: "vertical"
+                            size_hint_y: None
+                            height: self.minimum_height
+                            padding: [0, 0, 0, dp(32)]
 
-                        MDTextField:
-                            id: connectivity_local_groupid
-                            hint_text: "Optional WiFi/Ethernet Group ID"
-                            text: ""
-                            max_text_length: 128
-                            font_size: dp(24)
+                            MDTextField:
+                                id: connectivity_local_groupid
+                                hint_text: "Optional WiFi/Ethernet Group ID"
+                                text: ""
+                                max_text_length: 128
+                                font_size: dp(24)
 
-                        MDTextField:
-                            id: connectivity_local_ifac_netname
-                            hint_text: "Optional IFAC network name"
-                            text: ""
-                            font_size: dp(24)
-
-                        MDTextField:
-                            id: connectivity_local_ifac_passphrase
-                            hint_text: "Optional IFAC passphrase"
-                            text: ""
-                            font_size: dp(24)
+                            MDTextField:
+                                id: connectivity_local_ifac_netname
+                                hint_text: "Optional IFAC network name"
+                                text: ""
+                                font_size: dp(24)
 
+                            MDTextField:
+                                id: connectivity_local_ifac_passphrase
+                                hint_text: "Optional IFAC passphrase"
+                                text: ""
+                                font_size: dp(24)
 
 
                         MDBoxLayout:
                             orientation: "horizontal"
-                            # spacing: "24dp"
+                            padding: [0,0,dp(24),0]
                             size_hint_y: None
-                            height: dp(48)
+                            height: dp(24)
                             
                             MDLabel:
                                 id: connectivity_tcp_label
@@ -224,40 +282,47 @@ MDNavigationLayout:
 
                             MDSwitch:
                                 id: connectivity_use_tcp
+                                pos_hint: {"center_y": 0.3}
                                 active: False
 
 
-                        MDTextField:
-                            id: connectivity_tcp_host
-                            hint_text: "TCP Host"
-                            text: ""
-                            font_size: dp(24)
+                        MDBoxLayout:
+                            id: connectivity_tcp_fields
+                            orientation: "vertical"
+                            size_hint_y: None
+                            height: self.minimum_height
+                            padding: [0, 0, 0, dp(32)]
 
-                        MDTextField:
-                            id: connectivity_tcp_port
-                            hint_text: "TCP Port"
-                            text: ""
-                            font_size: dp(24)
+                            MDTextField:
+                                id: connectivity_tcp_host
+                                hint_text: "TCP Host"
+                                text: ""
+                                font_size: dp(24)
 
-                        MDTextField:
-                            id: connectivity_tcp_ifac_netname
-                            hint_text: "Optional IFAC network name"
-                            text: ""
-                            font_size: dp(24)
+                            MDTextField:
+                                id: connectivity_tcp_port
+                                hint_text: "TCP Port"
+                                text: ""
+                                font_size: dp(24)
 
-                        MDTextField:
-                            id: connectivity_tcp_ifac_passphrase
-                            hint_text: "Optional IFAC passphrase"
-                            text: ""
-                            font_size: dp(24)
+                            MDTextField:
+                                id: connectivity_tcp_ifac_netname
+                                hint_text: "Optional IFAC network name"
+                                text: ""
+                                font_size: dp(24)
 
+                            MDTextField:
+                                id: connectivity_tcp_ifac_passphrase
+                                hint_text: "Optional IFAC passphrase"
+                                text: ""
+                                font_size: dp(24)
 
 
                         MDBoxLayout:
                             orientation: "horizontal"
-                            # spacing: "24dp"
+                            padding: [0,0,dp(24),0]
                             size_hint_y: None
-                            height: dp(48)
+                            height: dp(24)
                             
                             MDLabel:
                                 id: connectivity_i2p_label
@@ -266,34 +331,41 @@ MDNavigationLayout:
 
                             MDSwitch:
                                 id: connectivity_use_i2p
+                                pos_hint: {"center_y": 0.3}
                                 active: False
 
 
-                        MDTextField:
-                            id: connectivity_i2p_b32
-                            hint_text: "I2P B32"
-                            text: ""
-                            font_size: dp(24)
+                        MDBoxLayout:
+                            id: connectivity_i2p_fields
+                            orientation: "vertical"
+                            size_hint_y: None
+                            height: self.minimum_height
+                            padding: [0, 0, 0, dp(32)]
 
-                        MDTextField:
-                            id: connectivity_i2p_ifac_netname
-                            hint_text: "Optional IFAC network name"
-                            text: ""
-                            font_size: dp(24)
+                            MDTextField:
+                                id: connectivity_i2p_b32
+                                hint_text: "I2P B32"
+                                text: ""
+                                font_size: dp(24)
 
-                        MDTextField:
-                            id: connectivity_i2p_ifac_passphrase
-                            hint_text: "Optional IFAC passphrase"
-                            text: ""
-                            font_size: dp(24)
+                            MDTextField:
+                                id: connectivity_i2p_ifac_netname
+                                hint_text: "Optional IFAC network name"
+                                text: ""
+                                font_size: dp(24)
 
+                            MDTextField:
+                                id: connectivity_i2p_ifac_passphrase
+                                hint_text: "Optional IFAC passphrase"
+                                text: ""
+                                font_size: dp(24)
 
 
                         MDBoxLayout:
                             orientation: "horizontal"
-                            # spacing: "24dp"
+                            padding: [0,0,dp(24),0]
                             size_hint_y: None
-                            height: dp(48)
+                            height: dp(24)
                             
                             MDLabel:
                                 id: connectivity_rnode_label
@@ -304,25 +376,117 @@ MDNavigationLayout:
                             MDSwitch:
                                 id: connectivity_use_rnode
                                 active: False
+                                pos_hint: {"center_y": 0.3}
                                 disabled: True
 
-                        MDLabel:
-                            id: rnode_support_info
-                            markup: True
-                            text: "[i]RNode support is in development[/i]"
+                        MDBoxLayout:
+                            id: connectivity_rnode_fields
+                            orientation: "vertical"
                             size_hint_y: None
-                            text_size: self.width, None
-                            height: self.texture_size[1]
+                            height: self.minimum_height
+                            padding: [0, 0, 0, dp(32)]
 
-                        MDTextField:
-                            id: connectivity_rnode_cid
-                            hint_text: "RNode Pairing ID"
-                            text: ""
-                            font_size: dp(24)
-                            disabled: True
+                            # MDLabel:
+                            #     id: rnode_support_info
+                            #     markup: True
+                            #     text: "[i]RNode support is in development[/i]"
+                            #     size_hint_y: None
+                            #     text_size: self.width, None
+                            #     height: self.texture_size[1]
+
+                            MDTextField:
+                                id: connectivity_rnode_cid
+                                hint_text: "RNode Pairing ID"
+                                text: ""
+                                font_size: dp(24)
+                                # disabled: True
+
+
+                        MDBoxLayout:
+                            orientation: "horizontal"
+                            padding: [0,0,dp(24),0]
+                            size_hint_y: None
+                            height: dp(24)
+                            
+                            MDLabel:
+                                id: connectivity_bluetooth_label
+                                text: "Connect via Bluetooth"
+                                font_style: "H6"
+                                disabled: True
+
+                            MDSwitch:
+                                id: connectivity_use_bluetooth
+                                active: False
+                                pos_hint: {"center_y": 0.3}
+                                disabled: True
+
+                        MDBoxLayout:
+                            id: connectivity_bluetooth_fields
+                            orientation: "vertical"
+                            size_hint_y: None
+                            height: self.minimum_height
+                            padding: [0, 0, 0, dp(32)]
+
+                            MDTextField:
+                                id: connectivity_bluetooth_cid
+                                hint_text: "Bluetooth Pairing ID"
+                                text: ""
+                                font_size: dp(24)
+                                # disabled: True
+
+
+                        MDBoxLayout:
+                            orientation: "horizontal"
+                            padding: [0,0,dp(24),0]
+                            size_hint_y: None
+                            height: dp(24)
+                            
+                            MDLabel:
+                                id: connectivity_modem_label
+                                text: "Connect via Radio Modem"
+                                font_style: "H6"
+                                disabled: True
+
+                            MDSwitch:
+                                id: connectivity_use_modem
+                                active: False
+                                pos_hint: {"center_y": 0.3}
+                                disabled: True
+
+                        MDBoxLayout:
+                            id: connectivity_modem_fields
+                            orientation: "vertical"
+                            size_hint_y: None
+                            height: self.minimum_height
+                            padding: [0, 0, 0, dp(32)]
+
+                            MDTextField:
+                                id: connectivity_modem_cid
+                                hint_text: "Modem Pairing ID"
+                                text: ""
+                                font_size: dp(24)
+                                # disabled: True
+
+
+                        MDBoxLayout:
+                            orientation: "horizontal"
+                            padding: [0,0,dp(24),0]
+                            size_hint_y: None
+                            height: dp(24)
+                            
+                            MDLabel:
+                                id: connectivity_transport_label
+                                text: "Enable Reticulum Transport"
+                                font_style: "H6"
+                                disabled: True
+
+                            MDSwitch:
+                                id: connectivity_enable_transport
+                                active: False
+                                pos_hint: {"center_y": 0.3}
+                                disabled: True
 
         
-
         MDScreen:
             name: "guide_screen"
             
@@ -331,20 +495,24 @@ MDNavigationLayout:
 
                 MDTopAppBar:
                     title: "Guide"
-                    elevation: 10
-                    pos_hint: {"top": 1}
+                    anchor_title: "left"
+                    elevation: 2
                     left_action_items:
                         [['menu', lambda x: nav_drawer.set_state("open")]]
+                    right_action_items:
+                        [
+                        ['close', lambda x: root.ids.screen_manager.app.close_guide_action(self)],
+                        ]
 
                 ScrollView:
                     id:guide_scrollview
 
                     MDBoxLayout:
                         orientation: "vertical"
-                        spacing: "24dp"
                         size_hint_y: None
                         height: self.minimum_height
-                        padding: dp(64)
+                        padding: [dp(35), dp(16), dp(35), dp(16)]
+
 
                         MDLabel:
                             id: guide_info
@@ -363,20 +531,23 @@ MDNavigationLayout:
 
                 MDTopAppBar:
                     title: "App & Version Information"
-                    elevation: 10
-                    pos_hint: {"top": 1}
+                    anchor_title: "left"
+                    elevation: 2
                     left_action_items:
                         [['menu', lambda x: nav_drawer.set_state("open")]]
+                    right_action_items:
+                        [
+                        ['close', lambda x: root.ids.screen_manager.app.close_information_action(self)],
+                        ]
 
                 ScrollView:
                     id:information_scrollview
 
                     MDBoxLayout:
                         orientation: "vertical"
-                        spacing: "24dp"
                         size_hint_y: None
                         height: self.minimum_height
-                        padding: dp(64)
+                        padding: [dp(35), dp(32), dp(35), dp(16)]
 
                         MDLabel:
                             id: information_info
@@ -395,8 +566,8 @@ MDNavigationLayout:
 
                 MDTopAppBar:
                     title: "Local Area Map"
-                    elevation: 10
-                    pos_hint: {"top": 1}
+                    anchor_title: "left"
+                    elevation: 2
                     left_action_items:
                         [['menu', lambda x: nav_drawer.set_state("open")]]
 
@@ -408,7 +579,8 @@ MDNavigationLayout:
                         spacing: "24dp"
                         size_hint_y: None
                         height: self.minimum_height
-                        padding: dp(64)
+                        padding: [dp(35), dp(35), dp(35), dp(35)]
+
 
                         MDLabel:
                             id: map_info
@@ -427,10 +599,14 @@ MDNavigationLayout:
 
                 MDTopAppBar:
                     title: "Encryption Keys"
-                    elevation: 10
-                    pos_hint: {"top": 1}
+                    anchor_title: "left"
+                    elevation: 2
                     left_action_items:
                         [['menu', lambda x: nav_drawer.set_state("open")]]
+                    right_action_items:
+                        [
+                        ['close', lambda x: root.ids.screen_manager.app.close_keys_action(self)],
+                        ]
 
                 ScrollView:
                     id:keys_scrollview
@@ -440,7 +616,8 @@ MDNavigationLayout:
                         spacing: "24dp"
                         size_hint_y: None
                         height: self.minimum_height
-                        padding: dp(64)
+                        padding: [dp(35), dp(35), dp(35), dp(35)]
+
 
                         MDLabel:
                             id: keys_info
@@ -449,6 +626,60 @@ MDNavigationLayout:
                             size_hint_y: None
                             text_size: self.width, None
                             height: self.texture_size[1]
+
+                        MDRectangleFlatIconButton:
+                            id: keys_display
+                            icon: "eye"
+                            text: "Display Identity Key"
+                            padding: [dp(0), dp(14), dp(0), dp(14)]
+                            icon_size: dp(24)
+                            font_size: dp(16)
+                            size_hint: [1.0, None]
+                            on_release: root.ids.screen_manager.app.identity_display_action(self)
+
+                        MDRectangleFlatIconButton:
+                            id: keys_copy
+                            icon: "file-key"
+                            text: "Copy Key To Clipboard"
+                            padding: [dp(0), dp(14), dp(0), dp(14)]
+                            icon_size: dp(24)
+                            font_size: dp(16)
+                            size_hint: [1.0, None]
+                            on_release: root.ids.screen_manager.app.identity_copy_action(self)
+
+                        MDRectangleFlatIconButton:
+                            id: keys_share
+                            icon: "upload-lock"
+                            text: "Send Key To Other App"
+                            padding: [dp(0), dp(14), dp(0), dp(14)]
+                            icon_size: dp(24)
+                            font_size: dp(16)
+                            size_hint: [1.0, None]
+                            on_release: root.ids.screen_manager.app.identity_share_action(self)
+
+                        MDBoxLayout:
+                            orientation: "vertical"
+                            # spacing: "24dp"
+                            size_hint_y: None
+                            height: self.minimum_height
+                            padding: [dp(0), dp(12), dp(0), dp(0)]
+
+                            MDTextField:
+                                id: key_restore_text
+                                hint_text: "Enter base32 key for import"
+                                mode: "rectangle"
+                                # size_hint: [1.0, None]
+                                pos_hint: {"center_x": .5}
+
+                        MDRectangleFlatIconButton:
+                            id: keys_restore
+                            icon: "download-lock"
+                            text: "Restore Identity From Key"
+                            padding: [dp(0), dp(14), dp(0), dp(14)]
+                            icon_size: dp(24)
+                            font_size: dp(16)
+                            size_hint: [1.0, None]
+                            on_release: root.ids.screen_manager.app.identity_restore_action(self)
         
 
         MDScreen:
@@ -459,8 +690,8 @@ MDNavigationLayout:
 
                 MDTopAppBar:
                     title: "Announce Stream"
-                    elevation: 10
-                    pos_hint: {"top": 1}
+                    anchor_title: "left"
+                    elevation: 2
                     left_action_items:
                         [['menu', lambda x: nav_drawer.set_state("open")]]
                     right_action_items:
@@ -496,8 +727,8 @@ MDNavigationLayout:
 
                 MDTopAppBar:
                     title: "Settings"
-                    elevation: 10
-                    pos_hint: {"top": 1}
+                    anchor_title: "left"
+                    elevation: 2
                     left_action_items:
                         [['menu', lambda x: nav_drawer.set_state("open")]]
                     right_action_items:
@@ -513,7 +744,8 @@ MDNavigationLayout:
                         spacing: "24dp"
                         size_hint_y: None
                         height: self.minimum_height
-                        padding: dp(16)
+                        padding: [dp(28), dp(16), dp(28), dp(16)]
+                        
 
                         MDLabel:
                             text: ""
@@ -556,8 +788,23 @@ MDNavigationLayout:
 
                         MDBoxLayout:
                             orientation: "horizontal"
-                            # spacing: "24dp"
                             size_hint_y: None
+                            padding: [0,0,dp(24),0]
+                            height: dp(48)
+                            
+                            MDLabel:
+                                text: "Dark Mode UI"
+                                font_style: "H6"
+
+                            MDSwitch:
+                                id: settings_dark_ui
+                                pos_hint: {"center_y": 0.3}
+                                active: False
+
+                        MDBoxLayout:
+                            orientation: "horizontal"
+                            size_hint_y: None
+                            padding: [0,0,dp(24),0]
                             height: dp(48)
                             
                             MDLabel:
@@ -566,27 +813,29 @@ MDNavigationLayout:
 
                             MDSwitch:
                                 id: settings_start_announce
+                                pos_hint: {"center_y": 0.3}
                                 active: False
 
                         MDBoxLayout:
                             orientation: "horizontal"
-                            # spacing: "24dp"
                             size_hint_y: None
+                            padding: [0,0,dp(24),0]
                             height: dp(48)
                             
                             MDLabel:
-                                text: "Deliver via LXMF Propagation Node by default"
+                                text: "Send via Propagation Node by default"
                                 font_style: "H6"
 
                             MDSwitch:
                                 id: settings_lxmf_delivery_by_default
+                                pos_hint: {"center_y": 0.3}
                                 disabled: False
                                 active: False
 
                         MDBoxLayout:
                             orientation: "horizontal"
-                            # spacing: "24dp"
                             size_hint_y: None
+                            padding: [0,0,dp(24),0]
                             height: dp(48)
                             
                             MDLabel:
@@ -595,13 +844,14 @@ MDNavigationLayout:
 
                             MDSwitch:
                                 id: settings_lxmf_sync_limit
+                                pos_hint: {"center_y": 0.3}
                                 disabled: False
                                 active: False
 
                         MDBoxLayout:
                             orientation: "horizontal"
-                            # spacing: "24dp"
                             size_hint_y: None
+                            padding: [0,0,dp(24),0]
                             height: dp(48)
                             
                             MDLabel:
@@ -610,13 +860,14 @@ MDNavigationLayout:
 
                             MDSwitch:
                                 id: settings_home_node_as_broadcast_repeater
+                                pos_hint: {"center_y": 0.3}
                                 active: False
                                 disabled: True
 
                         MDBoxLayout:
                             orientation: "horizontal"
-                            # spacing: "24dp"
                             size_hint_y: None
+                            padding: [0,0,dp(24),0]
                             height: dp(48)
                             
                             MDLabel:
@@ -625,12 +876,14 @@ MDNavigationLayout:
 
                             MDSwitch:
                                 id: settings_telemetry_to_home_node
+                                pos_hint: {"center_y": 0.3}
                                 disabled: True
                                 active: False
         
 
     MDNavigationDrawer:
         id: nav_drawer
+        radius: (0, dp(8), dp(8), 0)
 
         ContentNavigationDrawer:
             ScrollView:
@@ -735,18 +988,23 @@ MDNavigationLayout:
                                 on_release: root.ids.screen_manager.app.quit_action(self)
 
 <ListLXMessageCard>:
+    style: "filled"
+    elevation: 2
     padding: dp(8)
+    radius: [dp(4), dp(4), dp(4), dp(4)]
     size_hint: 1.0, None
     height: content_text.height + heading_text.height + dp(32)
     pos_hint: {"center_x": .5, "center_y": .5}
 
     MDRelativeLayout:
         size_hint: 1.0, None
-        # size: root.size
+        theme_text_color: "ContrastParentBackground"
 
         MDIconButton:
             id: msg_submenu
             icon: "dots-vertical"
+            # theme_text_color: 'Custom'
+            # text_color: rgba(255,255,255,216)
             pos:
                 root.width - (self.width + root.padding[0] + dp(4)), root.height - (self.height + root.padding[0] + dp(4))
 
@@ -755,6 +1013,8 @@ MDNavigationLayout:
             markup: True
             text: root.heading
             adaptive_size: True
+            # theme_text_color: 'Custom'
+            # text_color: rgba(255,255,255,100)
             pos: 0, root.height - (self.height + root.padding[0] + dp(8))
 
         MDLabel:
@@ -763,6 +1023,8 @@ MDNavigationLayout:
             # adaptive_size: True
             size_hint_y: None
             text_size: self.width, None
+            # theme_text_color: 'Custom'
+            # text_color: rgba(255,255,255,216)
             height: self.texture_size[1]
 
 <MsgSync>
@@ -796,6 +1058,7 @@ MDNavigationLayout:
         orientation: "horizontal"
         # spacing: "24dp"
         size_hint_y: None
+        padding: [0,0,dp(24),0]
         height: dp(48)
         MDLabel:
             id: trusted_switch_label
@@ -830,6 +1093,7 @@ MDNavigationLayout:
     MDBoxLayout:
         orientation: "horizontal"
         size_hint_y: None
+        padding: [0,0,dp(24),0]
         height: dp(48)
         MDLabel:
             id: "trusted_switch_label"
@@ -838,5 +1102,6 @@ MDNavigationLayout:
 
         MDSwitch:
             id: n_trusted
+            pos_hint: {"center_y": 0.3}
             active: False
 """
\ No newline at end of file
