@@ -6,7 +6,8 @@ from kivy.metrics import dp
 from kivy.core.clipboard import Clipboard
 from kivymd.uix.card import MDCard
 from kivymd.uix.menu import MDDropdownMenu
-from kivymd.uix.behaviors import RoundedRectangularElevationBehavior
+from kivymd.uix.behaviors import RoundedRectangularElevationBehavior, FakeRectangularElevationBehavior
+# from kivymd.uix.behaviors import CommonElevationBehavior
 from kivy.properties import StringProperty, BooleanProperty
 from kivy.uix.gridlayout import GridLayout
 from kivy.uix.boxlayout import BoxLayout
@@ -16,12 +17,13 @@ from kivymd.uix.dialog import MDDialog
 
 if RNS.vendor.platformutils.get_platform() == "android":
     from ui.helpers import ts_format, mdc
-    from ui.helpers import color_received, color_delivered, color_propagated, color_failed, color_unknown, intensity_msgs
+    from ui.helpers import color_received, color_delivered, color_propagated, color_failed, color_unknown, intensity_msgs_dark, intensity_msgs_light
 else:
     from .helpers import ts_format, mdc
-    from .helpers import color_received, color_delivered, color_propagated, color_failed, color_unknown, intensity_msgs
+    from .helpers import color_received, color_delivered, color_propagated, color_failed, color_unknown, intensity_msgs_dark, intensity_msgs_light
 
-class ListLXMessageCard(MDCard, RoundedRectangularElevationBehavior):
+# class ListLXMessageCard(MDCard, CommonElevationBehavior):
+class ListLXMessageCard(MDCard, FakeRectangularElevationBehavior):
     text = StringProperty()
     heading = StringProperty()
 
@@ -51,13 +53,18 @@ class Messages():
     def update(self):
         self.messages = self.app.sideband.list_messages(self.context_dest, self.latest_message_timestamp)
         if self.list == None:
-            layout = GridLayout(cols=1, spacing=16, padding=16, size_hint_y=None)
+            layout = GridLayout(cols=1, spacing=dp(16), padding=dp(16), size_hint_y=None)
             layout.bind(minimum_height=layout.setter('height'))
             self.list = layout
 
         if len(self.messages) > 0:
             self.update_widget()
 
+        if self.app.sideband.config["dark_ui"]:
+            intensity_msgs = intensity_msgs_dark
+        else:
+            intensity_msgs = intensity_msgs_light
+
         for w in self.widgets:
             m = w.m
             if m["state"] == LXMF.LXMessage.SENDING or m["state"] == LXMF.LXMessage.OUTBOUND:
@@ -91,6 +98,13 @@ class Messages():
 
 
     def update_widget(self):
+        if self.app.sideband.config["dark_ui"]:
+            intensity_msgs = intensity_msgs_dark
+            mt_color = [1.0, 1.0, 1.0, 0.8]
+        else:
+            intensity_msgs = intensity_msgs_light
+            mt_color = [1.0, 1.0, 1.0, 0.95]
+
         for m in self.messages:
             if not m["hash"] in self.added_item_hashes:
                 txstr = time.strftime(ts_format, time.localtime(m["sent"]))
@@ -122,7 +136,7 @@ class Messages():
                         heading_str = titlestr+"[b]Sent[/b] "+txstr+" [b]State[/b] Unknown"
 
                 else:
-                    msg_color = mdc("Green", intensity_msgs)
+                    msg_color = mdc(color_received, intensity_msgs)
                     heading_str = titlestr+"[b]Sent[/b] "+txstr+"\n[b]Received[/b] "+rxstr
 
                 item = ListLXMessageCard(
@@ -132,6 +146,12 @@ class Messages():
                 )
                 item.sb_uid = m["hash"]
                 item.m = m
+                item.ids.heading_text.theme_text_color = "Custom"
+                item.ids.heading_text.text_color = mt_color
+                item.ids.content_text.theme_text_color = "Custom"
+                item.ids.content_text.text_color = mt_color
+                item.ids.msg_submenu.theme_text_color = "Custom"
+                item.ids.msg_submenu.text_color = mt_color
 
                 def gen_del(mhash, item):
                     def x():
@@ -144,6 +164,7 @@ class Messages():
                         dialog = MDDialog(
                             text="Delete message?",
                             buttons=[ yes_button, no_button ],
+                            # elevation=0,
                         )
                         def dl_yes(s):
                             dialog.dismiss()
@@ -186,6 +207,8 @@ class Messages():
                     items=dm_items,
                     position="center",
                     width_mult=4,
+                    elevation=1,
+                    radius=dp(3),
                 )
 
                 def callback_factory(ref):
